@@ -4,12 +4,12 @@
 """
 
 from ctypes import *
-from pprint import pprint
 from .message_base import MessageBase
 
-MSG1200_NULL = b"\x00"*35
+class Message1200(MessageBase):
+    MSGLEN  = 35
+    MSGNULL = b"\x00" * MSGLEN
 
-class Message1200(BigEndianStructure, MessageBase):
     _pack_ = 1
     _fields_ = [
         ("time_stamp",              c_double),
@@ -33,5 +33,5 @@ class Message1200(BigEndianStructure, MessageBase):
     def encode(self):
         return bytes(self)
 
-    def dump(self):
-        pprint(self)
\ No newline at end of file
+    def getStationId(self):
+       return self.station_number 
\ No newline at end of file
