@@ -4,22 +4,23 @@
 """
 
 from ctypes import *
-from pprint import pprint
 from .message_base import MessageBase
 
-MSG20000_NULL = b"\x00"*68
 
-MSG20000_PAN_DIRECTION_LEFT = -1
-MSG20000_PAN_DIRECTION_NONE = 0
-MSG20000_PAN_DIRECTION_RIGHT = 1
-
-MSG20000_TILT_DIRECTION_UP = 1
-MSG20000_TILT_DIRECTION_NONE = 0
-MSG20000_TILT_DIRECTION_DOWN = -1
-
-class Message20000(BigEndianStructure, MessageBase):
+class Message20000(MessageBase):
     """Custom Message 20000 for continually Panning and Tilting EO payloads"""
     
+    MSGLEN  = 30
+    MSGNULL = b"\x00" * MSGLEN
+
+    PAN_DIRECTION_LEFT = -1
+    PAN_DIRECTION_NONE = 0
+    PAN_DIRECTION_RIGHT = 1
+
+    TILT_DIRECTION_UP = 1
+    TILT_DIRECTION_NONE = 0
+    TILT_DIRECTION_DOWN = -1
+
     _pack_ = 1
     _fields_ = [
         ("time_stamp",                          c_double),
@@ -41,5 +42,5 @@ class Message20000(BigEndianStructure, MessageBase):
     def encode(self):
         return bytes(self)
 
-    def dump(self):
-        pprint(self)
\ No newline at end of file
+    def getStationId(self):
+       return self.station_number 
\ No newline at end of file
