@@ -4,11 +4,12 @@
 """
 
 from ctypes import *
-from pprint import pprint
+from .message_base import MessageBase
+class MessageWrapper(MessageBase):
+    
+    MSGLEN  = 30
+    MSGNULL = b"\x00" * MSGLEN
 
-MESSAGE_WRAPPER_NULL = b"\x00" * 30
-MESSAGE_WRAPPER_LEN = 30
-class MessageWrapper(BigEndianStructure):
     _pack_ = 1
     _fields_ = [
         ("idd_version",             c_char*10),
@@ -27,8 +28,8 @@ class MessageWrapper(BigEndianStructure):
     def encode(self):
         return bytes(self)
 
-    def dump(self):
-        pprint(self)
+    def getStationId(self):
+       return None 
 
     def wrap_message(self, instance_id, type, msg, ack_needed):
         encoded_payload = msg.encode()
